_antonyms = {
    "ικανότητα": "αδυναμία",
    "ασυνήθιστος": "κανονικός",
    "καταργώ": "εγκαθιδρύω",
    "απουσία": "παρουσία",
    "απών": "παρόν",
    "μελλοντικός": "το παρελθόν",
    "απόλυτος": "συγγενής",
    "απέχω": "καταναλώνω",
    "αφηρημένη": "σκυρόδεμα",
    "αφθονία": "έλλειψη",
    "άφθονος": "σπάνιος",
    "αποδέχομαι": "απορρίπτω",
    "ομολογώ": "αρνούμαι",
    "δεκτός": "απαράδεκτος",
    "αποδοχή": "απόρριψη",
    "προσιτός": "απρόσιτος",
    "ακριβής": "ανακριβής",
    "αναγνωρίζεται": "μη αναγνωρισμένο",
    "γνωριμία": "ξένος",
    "ενεργω": "επωδός",
    "δράση": "εν δρασει",
    "ενεργός": "αδρανής",
    "υπάρχων": "εξαφανισμένος",
    "θορυβώδης": "ησυχια",
    "δραστηριότητα": "αδράνεια",
    "πραγματικός": "φανταστικός",
    "προσθέτω": "αφαιρώ",
    "πρόσθεση": "αφαίρεση",
    "επαρκής": "ανεπαρκής",
    "επίθετο": "ουσιαστικό",
    "αποδεκτός": "απαράδεκτος",
    "ενήλικας": "νεανικός",
    "προκαταβολή": "αποτραβιέμαι",
    "εμπρός": "όπισθεν",
    "γυρίζω": "πίσω",
    "πλεονέκτημα": "μειονέκτημα",
    "επιβεβαίωση": "αντιστροφή",
    "καταφατικός": "αρνητικός",
    "ουδέτερος": "θηλυκός",
    "πίσω": "γυρίζω",
    "ηλικία": "ξανανιώνω",
    "ηλικιωμένος": "νέος",
    "ανακίνηση": "ηρεμία",
    "συμφωνώ": "διαφωνώ",
    "ευχάριστος": "δυσάρεστος",
    "συμφωνία": "διαφωνία",
    "μεταβληθεί": "αμεταποίητος",
    "εναλλακτικό": "απεναντι απο",
    "ερασιτέχνης": "επαγγελματίας",
    "ασαφής": "ξεκάθαρος",
    "φιλικός": "δυσμενής",
    "αμφίβιος": "γήινος",
    "πρωκτικός": "από το στόμα",
    "ανάλογος": "ομόλογος",
    "ανάλυση": "παρασκευή",
    "αναλυτικός": "συνθετικός",
    "πρόγονος": "απόγονος",
    "γωνιώδης": "στρογγυλεμένες",
    "έμψυχος": "άψυχος",
    "απάντηση": "ερώτηση",
    "ανταγωνιστικός": "συνεργιστική",
    "προηγούμενος": "επιτυχία",
    "αντισηπτικό": "σηπτικός",
    "εμφάνιση": "εξαφάνιση",
    "εκτίμηση": "υποτίμηση",
    "έγκριση": "αποδοκιμασία",
    "εγκρίνω": "αποδοκιμάζω",
    "υδάτινος": "αμφίβιος",
    "γήινος": "ουράνιος",
    "υδαρής": "πύρινος",
    "μπράτσο": "αφοπλίζω",
    "ένοπλος": "άοπλος",
    "φθάνω": "άδεια",
    "αναβαίνω": "κατεβαίνω",
    "ανάβαση": "κατάβαση",
    "κοιμισμένος": "ξύπνιος",
    "συγκατάθεση": "διαφωνία",
    "ασυμμετρία": "συμμετρία",
    "αθεϊσμός": "θεϊσμός",
    "συνδέω": "αποσπώ",
    "επίθεση": "υπερασπίζω",
    "καταδιώκω": "υπερασπίζω",
    "προσοχή": "απροσεξία",
    "αξιοθεατο": "αποστροφή",
    "ακουστός": "μη ακουστός",
    "αύξηση": "σειρά",
    "θεία": "θείος",
    "εξουσιοδοτημένο": "ανεξουσιοδότητος",
    "αυτόματο": "εγχειρίδιο",
    "αποφύγει": "αντιμετωπίζω",
    "ξύπνιος": "κοιμισμένος",
    "αποτραβιέμαι": "προκαταβολή",
    "όπισθεν": "κεφάλι",
    "ιστορικό": "σε πρώτο πλάνο",
    "οπισθοδρομικός": "προοδευτικός",
    "αντιστροφη": "όψη",
    "κακό": "καλός",
    "κακία": "καλοσύνη",
    "ισορροπημένη": "ανισόρροπος",
    "αρκούδα": "ταύρος",
    "πανεμορφη": "άσχημος",
    "ομορφιά": "ασχημία",
    "αρχίζουν": "τέλος",
    "αρχή": "να σταματήσει",
    "νωρίς": "αργά",
    "πίστη": "απιστία",
    "στροφή": "ισιώνω",
    "αγαθός": "κακόηθες",
    "μεγάλο": "μικρό",
    "γέννηση": "θάνατος",
    "αμφιφυλόφιλος": "ομοφυλόφιλος",
    "μαύρος": "άσπρο",
    "ευλογώ": "κατάρα",
    "ευλογημένος": "καταραμένος",
    "αναίμακτος": "αιματηρός",
    "αιματηρός": "αναίμακτος",
    "θολούρα": "συγκεντρώνω",
    "βρασμός": "πάγωμα",
    "τολμηρός": "συνεσταλμένος",
    "τόλμη": "δειλία",
    "δανείζομαι": "δανείζω",
    "οφειλέτης": "πιστωτής",
    "κάτω μέρος": "μπλουζα",
    "όριο": "άδετος",
    "αγόρι": "κορίτσι",
    "μποϋκοτάζ": "υποστηρίζω",
    "διακοπή": "επισκευή",
    "εύθραυστος": "άθραυστος",
    "λαμπρύνω": "αμαυρώνω",
    "φωτίζω": "αμαυρώνω",
    "σπασμένος": "άθραυστος",
    "αδελφός": "αδελφή",
    "ταύρος": "αρκούδα",
    "απασχολημένος": "άεργος",
    "δουλειά": "άεργος",
    "αγορά": "πουλώ",
    "ηρεμία": "ανακίνηση",
    "ικανός": "ανίκανος",
    "χωρητικότητα": "ανικανότητα",
    "μετρητά": "πίστωση",
    "χρέωση": "εκπλήρωση",
    "κέντρο": "αριστερά",
    "εγκεφαλικός": "συναισθηματική",
    "βεβαιότητα": "αβεβαιότητα",
    "αλλαγή": "διαμονή",
    "παρεκκλίνω": "διαμονή",
    "κίνηση": "διαμονή",
    "μεταβλητός": "αμετάβλητος",
    "άλλαξε": "αμετάβλητος",
    "κατατάσσω": "εκπλήρωση",
    "φτηνός": "ακριβός",
    "κέφι": "κανω παραπονα",
    "χαρούμενος": "θλιμμένος",
    "παιδί": "μητρική εταιρεία",
    "πολίτης": "στρατος",
    "απαίτηση": "τίμημα",
    "σαφήνεια": "αδιαφάνεια",
    "προεξοχή": "αφάνεια",
    "διαφάνεια": "αδιαφάνεια",
    "καθαρη": "ακάθαρτος",
    "κλήρος": "λαϊκοί",
    "κληρικός": "λαϊκός",
    "κοντά": "άνοιξε",
    "κλειστό": "άνοιξε",
    "κλειστός": "άνοιξε",
    "εγγύτητα": "ειλικρίνεια",
    "παραλιακός": "ενδοχώρα",
    "συναφής": "ασυνάρτητος",
    "κρύο": "ζεστό",
    "εγγύηση": "γραμμική",
    "κωμωδία": "τραγωδία",
    "άνεση": "δυσφορία",
    "κοινός": "ασυνήθης",
    "σύμφωνος": "ασύμβατες",
    "επάρκεια": "ανεπάρκεια",
    "ανταγωνισμός": "συνεργασία",
    "κανω παραπονα": "κέφι",
    "πληρότητα": "κενότητα",
    "συγκρότημα": "απλός",
    "χημική ένωση": "απλός",
    "υποχωρητικός": "προκλητικός",
    "περιπλέκω": "απλοποιώ",
    "κοίλος": "στερεός",
    "έπαρση": "ταπεινότητα",
    "υπερηφάνεια": "ταπεινότητα",
    "συγκέντρωση": "διανομή",
    "ομόκεντρος": "εκκεντρικός",
    "σύλληψη": "παρανόηση",
    "ενδιαφερόμενος": "αδιάφορος",
    "σκυρόδεμα": "αφηρημένη",
    "επιβεβαιωμένος": "ανεξακρίβωτος",
    "αντιμετωπίζω": "αποφύγει",
    "συνδετικός": "διαζευκτικός",
    "συνδέω-συωδεομαι": "αποσυνδέω",
    "συνδεδεμένος": "άσχετος",
    "συνείδηση": "αναισθησία",
    "συντηρητικός": "φιλελεύθερος",
    "συντηρώ": "απόβλητα",
    "διακριτικός": "απερίσκεπτος",
    "συνοχή": "ασυνέπεια",
    "σύμφωνο": "φωνήεν",
    "εμφανής": "άσημος",
    "συνταγματικός": "αντισυνταγματικός",
    "καταναλώνω": "απέχω",
    "περιεχόμενο": "δυσαρέσκεια",
    "συνεχής": "διακεκομμένος",
    "συνέχιση": "διακοπή",
    "να συνεχίσει": "διακόπτω",
    "συνέχεια": "ασυνέχεια",
    "σύμβαση": "επεκτείνουν",
    "συνεσταλμένος": "τολμηρός",
    "συστολή": "επέκταση",
    "βολικός": "άβολος",
    "συμβατικός": "πρωτότυπος",
    "συγκλίνω": "αποκλίνω",
    "σύγκλιση": "απόκλιση",
    "συγκεντρούμενος": "αποκλίνων",
    "κυρτός": "ευθεία",
    "πεπεισμένοι": "ακατάπειστος",
    "δροσερός": "θερμότητα",
    "συνεργασία": "ανταγωνισμός",
    "κοσμοπολίτικος": "επαρχιακός",
    "θάρρος": "δειλία",
    "κάλυμμα": "αποκαλύπτω",
    "συγκαλυμμένος": "φανερός",
    "δειλία": "τόλμη",
    "πίστωση": "χρέωση",
    "πιστωτής": "οφειλέτης",
    "κριτικάρω": "έπαινος",
    "κραυγή": "ψίθυρος",
    "θεραπεύσιμος": "ανίατος",
    "κατάρα": "ευλογώ",
    "καταραμένος": "ευλογημένος",
    "τομή": "άκοπος",
    "κίνδυνος": "ασφάλεια",
    "επικίνδυνος": "ασφαλής",
    "σκοτάδι": "ελαφρότητα",
    "αμαυρώνω": "φωτίζω",
    "βαρύτητα": "ελαφρότητα",
    "κόρη": "υιός",
    "ημέρα": "νύχτα",
    "κουφός": "ακρόαση",
    "θάνατος": "γέννηση",
    "ευπρέπεια": "απρέπεια",
    "κόσμιος": "απρεπής",
    "φυλλοβόλος": "αειθαλής",
    "απόφαση": "αναποφάσιστο",
    "αποφασιστικός": "αναποφάσιστος",
    "πτώση": "αυξανόμενες",
    "μείωση": "αύξηση",
    "μειώθηκε": "αυξήθηκε",
    "ήττα": "νίκη",
    "υπερασπίζω": "καταδιώκω",
    "εναγόμενος": "ενάγων",
    "άμυνα": "δίωξη",
    "αμυντικός": "προσβλητικός",
    "προκλητικός": "υποχωρητικός",
    "έλλειμμα": "οδηγω",
    "ορίζεται": "απροσδιόριστος",
    "ξεφούσκωμα": "πληθωρισμός",
    "καθυστέρηση": "βιασύνη",
    "αργοπορώ": "βιασύνη",
    "ζήτηση": "προμήθεια",
    "αρνούμαι": "απαίτηση",
    "απορρίπτω": "αποδέχομαι",
    "εξαρτώμενος": "ανεξάρτητος",
    "κατάθεση": "αποσύρω",
    "υποτίμηση": "εκτίμηση",
    "κατάθλιψη": "χαρούμενος",
    "κατεβαίνω": "αναβαίνω",
    "απόγονος": "πρόγονος",
    "κατάβαση": "ανάβαση",
    "περιγραφικός": "εντεταλμένος",
    "επιθυμητός": "ανεπιθύμητος",
    "απελπισία": "ελπίδα",
    "απελπισμένος": "ελπιδοφόρος",
    "καταστράφηκε από": "διατηρούνται",
    "αποσπώ": "συνδέω",
    "μεταβίβαση": "εξέλιξη",
    "διαφέρω": "ίσος",
    "άνισος": "ίσος",
    "διαφορά": "ομοιότητα",
    "δύσκολος": "εύκολος",
    "ανήσυχος": "εύκολος",
    "δυσκολία": "ευκολία",
    "επιμελής": "αμελής",
    "διάλυση": "συγκέντρωση",
    "διανομή": "συγκέντρωση",
    "βρώμικος": "καθαρη",
    "ακάθαρτος": "καθαρη",
    "καθιστώ ανίκανο": "επιτρέπω",
    "μειονέκτημα": "πλεονέκτημα",
    "διαφωνώ": "συμφωνώ",
    "δυσάρεστος": "ευχάριστος",
    "διαφωνία": "συγκατάθεση",
    "εξαφάνιση": "εμφάνιση",
    "αποδοκιμασία": "έγκριση",
    "αποδοκιμάζω": "εγκρίνω",
    "αφοπλίζω": "μπράτσο",
    "εκπλήρωση": "κατατάσσω",
    "τίμημα": "απαίτηση",
    "δυσφορία": "άνεση",
    "αποσυνδέω": "συνδέω-συωδεομαι",
    "δυσαρέσκεια": "ικανοποίηση",
    "διακοπή": "συνέχιση",
    "διακόπτω": "να συνεχίσει",
    "ασυνέχεια": "συνέχεια",
    "διακεκομμένος": "συνεχής",
    "αποθαρρύνουν": "ενθαρρύνω",
    "αποθάρρυνση": "ενθάρρυνση",
    "απαγκιστρώνω": "αρραβωνιάζω",
    "ανέντιμος": "τίμιος",
    "ατιμία": "τιμή",
    "απολυμαίνω": "μολύνω",
    "αποσυνθέτω": "ενσωματώνουν",
    "διαζευκτικός": "συνδετικός",
    "αντιπάθεια": "αρέσκεια",
    "εκτοπίζω": "οίκημα",
    "ανυπακοή": "υπακοή",
    "ανυπάκουος": "υπάκουος",
    "απειθώ": "υπακούω",
    "διαταραχή": "σειρά",
    "άτακτα": "τακτικός",
    "αποδιοργανωμένη": "διοργάνωσε",
    "αδιοργάνωτος": "διοργάνωσε",
    "μη ικανοποιημένοι": "ευχαριστημένος",
    "ανασκευάζω": "αποδεικνύω",
    "καθιστώ ακατάλληλο": "έχω τα προσόντα",
    "ανυπόληπτος": "ευυπόληπτος",
    "ανυποληψία": "υπόληψη",
    "έλλειψη σεβασμού": "σεβασμός",
    "ασεβής": "ταπεινός",
    "κακή υπηρεσία": "υπηρεσία",
    "ανόμοιος": "παρόμοιος",
    "παραφωνία": "αρμονία",
    "αποτρέπω": "πείθω",
    "απομακρυσμένη": "εγγύτατος",
    "μακρινός": "κοντά",
    "άνοιξε": "κλειστός",
    "ευδιάκριτος": "δυσδιάκριτος",
    "δυσπιστία": "εμπιστοσύνη",
    "ημερήσιος": "νυκτερινός",
    "αποκλίνω": "συγκλίνω",
    "απόκλιση": "σύγκλιση",
    "αποκλίνων": "συγκεντρούμενος",
    "διαιρέστε": "ενώνω",
    "χωριστά": "πολλαπλασιάζω",
    "διαιρεμένη": "ενωμένος",
    "διαιρετός": "αδιαίρετος",
    "οικιακός": "ξένο",
    "ντόπιος": "ξένο",
    "κυρίαρχο": "υφιστάμενος",
    "αδρανές": "ενεργός",
    "εξαφανισμένος": "υπάρχων",
    "αδρανής": "ενεργός",
    "παθητικός": "ενεργός",
    "ησυχια": "θορυβώδης",
    "διπλό": "μονόκλινο",
    "πολλαπλούς": "μονόκλινο",
    "περιστέρι": "γεράκι",
    "δραματικός": "λυρικός",
    "ξηρός": "βρεγμένος",
    "θυμώνω": "γλυκαίνω",
    "λόγω": "υπερβολικός",
    "αμβλύς": "ακονίζω",
    "ισοπεδώνω": "ακονίζω",
    "βαφή": "γεννημένος",
    "ευκολία": "δυσκολία",
    "εύκολος": "ανήσυχος",
    "άμπωτη": "παλίρροια",
    "εκκεντρικός": "ομόκεντρος",
    "μορφωμένος": "αμόρφωτος",
    "αποτελεσματικός": "ανεπαρκής",
    "αποδοτικότητα": "ανεπάρκεια",
    "έξοδος": "εισαγω",
    "ελαστικό": "όχι ελαστικός",
    "επιλέξιμες": "ακατάλληλος",
    "συναισθηματική": "εγκεφαλικός",
    "εμπειρικός": "θεωρητικός",
    "κενότητα": "πληρότητα",
    "αδειάζω": "γεμάτος",
    "λεπτός": "πυκνώνω",
    "επιτρέπω": "καθιστώ ανίκανο",
    "ενθαρρύνω": "αποθαρρύνουν",
    "ενθάρρυνση": "αποθάρρυνση",
    "τέλος": "αρχή",
    "κατάληξη": "πρόθεμα",
    "μέσης": "νωρίς",
    "ενδημικός": "κοσμοπολίτικος",
    "επαρχιακός": "κοσμοπολίτικος",
    "ενεργητικός": "ληθαργικός",
    "επιβάλλω": "εξαιρώ",
    "αρραβωνιάζω": "απαγκιστρώνω",
    "απολαμβάνω": "υποφέρω",
    "εισαγω": "έξοδος",
    "ίσος": "άνισος",
    "ισότητα": "ανισότητα",
    "ισημερινού": "πολικός",
    "δίκαιος": "άδικος",
    "διφορούμενος": "ξεκάθαρος",
    "εξάλειψη": "ρεκόρ",
    "εγκαθιδρύω": "καταργώ",
    "περιστασιακή": "ήσυχος",
    "αειθαλής": "φυλλοβόλος",
    "εξέλιξη": "μεταβίβαση",
    "αποκλεισμός": "συμπερίληψη",
    "εξαιρώ": "επιβάλλω",
    "αποπνέω": "εισπνέω",
    "υπαρκτός": "ανύπαρκτος",
    "επεκτείνουν": "σύμβαση",
    "αναπτυγμένος": "συνεσταλμένος",
    "επέκταση": "κάμψη",
    "αναμενόμενος": "απροσδόκητος",
    "ακριβός": "φτηνός",
    "έμπειρος": "άπειρος",
    "εξαγωγή": "εισαγωγή",
    "εξπρές": "τοπικός",
    "γενικός": "ειδικός",
    "εθνικός": "διεθνές",
    "εξωτερικός": "εσωτερικός",
    "εξωτερικά": "εσωτερικώς",
    "σβήνω": "ανάβω",
    "extramural": "εντός των τείχων",
    "έκτακτος": "συνήθης",
    "έλλειψη": "αφθονία",
    "τρέξιμο": "ορθοστασία",
    "αποτυχία": "επιτυχία",
    "έκθεση": "άδικος",
    "πιστός": "άπιστος",
    "σειρά": "αύξηση",
    "σφαλερός": "αλάνθαστος",
    "ψεύδος": "αλήθεια",
    "ψευτιά": "αλήθεια",
    "φήμη": "κακοφημία",
    "οικείος": "άγνωστος",
    "φαντασία": "πεδιάδα",
    "λίπος": "λεπτός",
    "γεμάτος": "αδειάζω",
    "πυκνός": "λεπτός",
    "πυκνώνω": "λεπτός",
    "πατέρας": "μητέρα",
    "πανίδα": "χλωρίδα",
    "ευνοϊκός": "δυσμενής",
    "ομοσπονδιακός": "ενιαία",
    "θηλυκός": "ουδέτερος",
    "θηλυκότητα": "ανδρισμός",
    "εύφορος": "στείρος",
    "πιστότητα": "απιστία",
    "εικόνα": "έδαφος",
    "γέμισμα": "αδειάζω",
    "εύρημα": "χάνω",
    "φινίρισμα": "αρχή",
    "να σταματήσει": "αρχή",
    "πεπερασμένος": "άπειρος",
    "φωτιά": "ενοικίαση",
    "κάμψη": "επέκταση",
    "φλοτέρ": "νεροχύτης",
    "πηγή": "νεροχύτης",
    "χλωρίδα": "πανίδα",
    "συγκεντρώνω": "θολούρα",
    "εχθρός": "φίλος",
    "πτυχή": "ξεδιπλωθεί",
    "ακολουθηστε": "προηγούμαι",
    "πετυχαίνω": "προηγούμαι",
    "οπαδός": "ηγέτης",
    "τρέλα": "σοφία",
    "ανόητος": "σοφός",
    "πόδι": "κεφάλι",
    "ουρά": "κεφάλι",
    "απαγορεύω": "άδεια",
    "σε πρώτο πλάνο": "ιστορικό",
    "ξένο": "ντόπιος",
    "ξεχνάμε": "θυμάμαι",
    "επιεικής": "ανελέητος",
    "φορμαλισμός": "μίμηση",
    "τυχερός": "άτυχος",
    "προς τα εμπρός": "αντιστροφη",
    "όψη": "αντιστροφη",
    "βρωμερός": "έκθεση",
    "άδικος": "δίκαιος",
    "βρέθηκαν": "χαμένος",
    "αδελφικός": "πανομοιότυπο",
    "πάγωμα": "βρασμός",
    "συχνάζω": "σπάνιος",
    "συχνά": "σπάνια",
    "φίλος": "εχθρός",
    "κεφάλι": "ουρά",
    "λειτουργικός": "οργανικός",
    "ανόργανος": "οργανικός",
    "κέρδος": "απώλεια",
    "αεριώδης": "στερεός",
    "μαζεύω": "τέντωμα",
    "γενικότητα": "λεπτομέρεια",
    "γενναιόδωρος": "τσιγκούνης",
    "κορίτσι": "αγόρι",
    "καλός": "κακό",
    "καλοσύνη": "κακία",
    "βαθμιαίος": "αιφνίδιος",
    "ευγνώμων": "αχάριστος",
    "μεγαλύτερη": "μικρότερος",
    "πράσινος": "ώριμος",
    "ακαθάριστο": "καθαρά",
    "έδαφος": "εικόνα",
    "ενοχή": "αθωότητα",
    "ένοχος": "αθώος",
    "ευτυχώς": "δυστυχώς",
    "ευτυχία": "δυστυχία",
    "ευτυχισμένος": "δυστυχής",
    "σκληρότητα": "απαλότητα",
    "ένταση": "απαλότητα",
    "οξύτητα": "απαλότητα",
    "αρμονία": "παραφωνία",
    "μισώ": "αγάπη",
    "μισητός": "αξιαγάπητος",
    "γεράκι": "περιστέρι",
    "υγιής": "παράφρων",
    "ακρόαση": "κουφός",
    "θερμότητα": "δροσερός",
    "ουράνιος": "γήινος",
    "ανομοιογένεια": "ομοιογένεια",
    "κρύβω": "προβολή",
    "ενοικίαση": "φωτιά",
    "κτύπημα": "δεσποινίδα",
    "άγιος": "ανίερος",
    "ομοιογένεια": "ανομοιογένεια",
    "ομόλογος": "ανάλογος",
    "ομοφυλόφιλος": "αμφιφυλόφιλος",
    "τίμιος": "ανέντιμος",
    "τιμιότητα": "ατιμία",
    "τιμή": "ατιμία",
    "ελπίδα": "απελπισία",
    "ελπιδοφόρος": "απελπισμένος",
    "οριζόντιος": "κατακόρυφος",
    "εχθρικός": "φιλικός",
    "δυσμενής": "ευνοϊκός",
    "ζεστό": "κρύο",
    "ταπεινός": "ασεβής",
    "ταπεινότητα": "υπερηφάνεια",
    "πεινασμένος": "διψασμένος",
    "πανομοιότυπο": "αδελφικός",
    "άεργος": "δουλειά",
    "πύρινος": "υδαρής",
    "ανάβω": "σβήνω",
    "αγνοώ": "ειδοποίηση",
    "παράνομος": "νόμιμος",
    "παρανομία": "νομιμότητα",
    "δυσανάγνωστος": "ευανάγνωστος",
    "παράλογος": "λογικός",
    "μίμηση": "φορμαλισμός",
    "επουσιώδης": "υλικό",
    "άωρο": "λήξη",
    "ανυπολόγιστος": "μετρητός",
    "ανήθικος": "ηθικός",
    "ανηθικότητα": "ηθική",
    "αθάνατος": "θνητός",
    "αθανασία": "θνησιμότητα",
    "αμετάβλητος": "άλλαξε",
    "αμεροληψία": "μεροληψία",
    "αδιάβατος": "μέτριος",
    "ανυπομονησία": "υπομονή",
    "ανυπόμονος": "υπομονετικος",
    "ανεπαίσθητος": "αντιληπτός",
    "ατέλεια": "πληρότητα",
    "αδιαπέραστος": "διαπερατός",
    "είναι απαράδεκτο": "επιτρεπτός",
    "απρόσωπος": "προσωπικός",
    "αγενής": "ευγενικός",
    "εισαγωγή": "εξαγωγή",
    "σπουδαίος": "ανευ σημασιας",
    "αδύνατο": "δυνατότητα",
    "ανίκανος": "ικανός",
    "απίθανος": "πιθανός",
    "βελτίωση": "πτώση",
    "ασύνετος": "συνετός",
    "ακαθαρσία": "καθαρότητα",
    "αδυναμία": "δύναμη",
    "απρόσιτος": "προσιτός",
    "ανακριβής": "ακριβής",
    "εν δρασει": "δράση",
    "αδράνεια": "δραστηριότητα",
    "ανεπαρκής": "επαρκής",
    "απαράδεκτος": "αποδεκτός",
    "άψυχος": "έμψυχος",
    "απροσεξία": "προσοχή",
    "μη ακουστός": "ακουστός",
    "ανικανότητα": "επάρκεια",
    "κεκλιμένος": "οριζόντιος",
    "κατακόρυφος": "οριζόντιος",
    "συμπερίληψη": "αποκλεισμός",
    "ασυνάρτητος": "συναφής",
    "ασύμβατες": "σύμφωνος",
    "απερίσκεπτος": "διακριτικός",
    "ασυνέπεια": "συνοχή",
    "άσημος": "εμφανής",
    "άβολος": "βολικός",
    "αυξάνουν": "μείωση",
    "αυξήθηκε": "μειώθηκε",
    "ανίατος": "θεραπεύσιμος",
    "απρέπεια": "ευπρέπεια",
    "απρεπής": "κόσμιος",
    "αναποφάσιστο": "απόφαση",
    "αναποφάσιστος": "αποφασιστικός",
    "ανεξάρτητος": "εξαρτώμενος",
    "δυσδιάκριτος": "ευδιάκριτος",
    "αδιαίρετος": "διαιρετός",
    "μέσα": "εξωτερικου χωρου",
    "ατελέσφορος": "αποτελεσματικός",
    "ανεπάρκεια": "επάρκεια",
    "όχι ελαστικός": "ελαστικό",
    "ακατάλληλος": "επιλέξιμες",
    "ανισότητα": "ισότητα",
    "άπειρος": "πεπερασμένος",
    "αλάνθαστος": "σφαλερός",
    "κακοφημία": "φήμη",
    "μολύνω": "απολυμαίνω",
    "κατώτερος": "αρχαιότερος",
    "κατωτερότητα": "υπεροχή",
    "απιστία": "πίστη",
    "πληθωρισμός": "ξεφούσκωμα",
    "προειδοποίητος": "απληροφόρητος",
    "σπάνιος": "άφθονος",
    "σπάνια": "συχνά",
    "είσοδος": "έξοδος",
    "κατοικημένη": "ακατοίκητος",
    "εισπνέω": "αποπνέω",
    "αδικία": "δικαιοσύνη",
    "ενδοχώρα": "παραλιακός",
    "αθωότητα": "ενοχή",
    "αθώος": "ένοχος",
    "αβλαβής": "επιβλαβής",
    "παράφρων": "υγιής",
    "παράνοια": "λογική",
    "ανασφάλεια": "ασφάλεια",
    "ασημαντότητα": "σημασία",
    "ασήμαντος": "σημαντικός",
    "αδιάλυτος": "διαλυτός",
    "αφερεγγυότητα": "φερεγγυότητα",
    "αφερέγγυος": "διαλυτικό μέσο",
    "αστάθεια": "σταθερότητα",
    "ενόργανος": "φωνητικός",
    "ανεπαρκώς": "επαρκώς",
    "ενσωματώνουν": "αποσυνθέτω",
    "ενσωμάτωση": "διαχωρισμός",
    "νοημοσύνη": "βλακεία",
    "καταληπτός": "ακατάληπτος",
    "προορίζονται": "ακούσιος",
    "εκ προθέσεως": "ακούσια",
    "ενδιαφέρων": "πληκτικός",
    "εσωτερικό": "εξωτερικός",
    "ενδιάμεσος": "τερματικό",
    "εσωτερικός": "εξωτερικός",
    "εσωτερικώς": "εξωτερικά",
    "διεθνές": "εθνικός",
    "τοπικός": "γενικός",
    "μισαλλοδοξία": "ανοχή",
    "μισαλλόδοξος": "ανεκτικός",
    "ατίθασος": "ήμερος",
    "εντός των τείχων": "extramural",
    "αόρατο": "ορατότητα",
    "αόρατος": "ορατός",
    "ακούσιος": "προορίζονται",
    "ακανόνιστος": "τακτικός",
    "παρατυπία": "κανονικότητα",
    "άσχετος": "σχετίζεται με",
    "ανεύθυνος": "υπεύθυνος",
    "θέμα": "ανάκληση",
    "άρθρωση": "ξεχωριστός",
    "χαρά": "λύπη",
    "δικαιοσύνη": "αδικία",
    "νεανικός": "ενήλικας",
    "kern": "kern",
    "είδος": "αφιλοφρών",
    "βασιλιάς": "βασίλισσα",
    "λαϊκοί": "κλήρος",
    "αργά": "γρήγορα",
    "γέλιο": "κραυγή",
    "νόμιμος": "παράνομος",
    "αμελής": "επιμελής",
    "χαλαρή": "σε υπερένταση",
    "λαϊκός": "κληρικός",
    "οδηγω": "έλλειμμα",
    "ηγέτης": "οπαδός",
    "άδεια": "απαγορεύω",
    "αριστερά": "κέντρο",
    "νομικός": "παράνομος",
    "νομιμότητα": "παρανομία",
    "νομιμοποιώ": "εκτός νόμου",
    "ευανάγνωστος": "δυσανάγνωστος",
    "δανείζω": "δανείζομαι",
    "δανειστής": "οφειλέτης",
    "επιμηκύνω": "βραχύνω",
    "μικρότερος": "μεγαλύτερη",
    "ληθαργικός": "ενεργητικός",
    "επίπεδο": "αύξηση",
    "πιο χαμηλα": "αύξηση",
    "φιλελεύθερος": "συντηρητικός",
    "ψέμα": "στάση",
    "απόδοση παραγωγής": "στάση",
    "φως": "σκοτάδι",
    "ελαφρότητα": "βαρύτητα",
    "αρέσκεια": "αντιπάθεια",
    "περιωρισμένος": "απεριόριστος",
    "γραμμική": "εγγύηση",
    "υγρό": "αεριώδης",
    "στερεός": "κοίλος",
    "ειδικός": "γενικός",
    "τοποθεσία": "στούντιο",
    "κλειδαριά": "ξεκλείδωμα",
    "οίκημα": "εκτοπίζω",
    "λογικός": "παράλογος",
    "μακρύς": "μικρός",
    "ψηλός": "μικρός",
    "αμολάω": "σκληρύνω",
    "χάνω": "εύρημα",
    "απώλεια": "κέρδος",
    "χαμένος": "βρέθηκαν",
    "αξιαγάπητος": "μισητός",
    "αγάπη": "μισώ",
    "λυρικός": "δραματικός",
    "μείζων": "ανήλικος",
    "η πλειοψηφία": "μειονότητα",
    "φτιαχνω, κανω": "διακοπή",
    "επισκευή": "διακοπή",
    "αρσενικός": "θηλυκός",
    "κακόβουλος": "αγαθός",
    "κακόηθες": "αγαθός",
    "εγχειρίδιο": "αυτόματο",
    "μαρκαρισμένος": "αβαθμολόγητος",
    "παντρεμένος": "άγαμος",
    "αρρενωπός": "θηλυκός",
    "ανδρισμός": "θηλυκότητα",
    "μάσκα": "ανακαλύπτω",
    "υλικό": "επουσιώδης",
    "μητρικός": "πατρικός",
    "λήξη": "άωρο",
    "ανώτατο όριο": "ελάχιστο",
    "μετρητός": "ανυπολόγιστος",
    "διανοητικός": "φυσικός",
    "εύσπλαχνος": "ανηλεής",
    "ανηλεής": "εύσπλαχνος",
    "στρατος": "πολίτης",
    "μυαλό": "ξεχνάμε",
    "θυμάμαι": "ξεχνάμε",
    "ελάχιστο": "ανώτατο όριο",
    "ανήλικος": "μείζων",
    "μειονότητα": "η πλειοψηφία",
    "παρανόηση": "σύλληψη",
    "δεσποινίδα": "κτύπημα",
    "τραπεζίτης": "μοριακός",
    "μοριακός": "τραπεζίτης",
    "ηθικός": "ανήθικος",
    "ηθική": "ανηθικότητα",
    "θνητός": "αθάνατος",
    "θνησιμότητα": "αθανασία",
    "μητέρα": "πατέρας",
    "πολλαπλασιάζω": "χωριστά",
    "ενώνω": "διαιρέστε",
    "ευμετάβλητος": "αμετάβλητος",
    "ναδίρ": "ζενίθ",
    "στενός": "ευρύνω",
    "γεννημένος": "βαφή",
    "αρνητικός": "ουδέτερος",
    "ανιψιός": "ανηψιά",
    "καθαρά": "ακαθάριστο",
    "ανηψιά": "ανιψιός",
    "νύχτα": "ημέρα",
    "νυκτερινός": "ημερήσιος",
    "ονομαστικός": "πραγματικός",
    "φανταστικός": "πραγματικός",
    "ανύπαρκτος": "υπαρκτός",
    "κανονικός": "ασυνήθιστος",
    "ειδοποίηση": "αγνοώ",
    "επιβλαβής": "αβλαβής",
    "αριθμητικός": "προφορικός",
    "υπακοή": "ανυπακοή",
    "υπάκουος": "ανυπάκουος",
    "υπακούω": "απειθώ",
    "σκοπός": "υποκειμενικός",
    "υποχρεωτικός": "προαιρετικός",
    "λοξός": "κάθετος",
    "αφάνεια": "προεξοχή",
    "αδιαφάνεια": "διαφάνεια",
    "κατειλημμένος": "αδειανός",
    "αδίκημα": "άμυνα",
    "δίωξη": "άμυνα",
    "προσβλητικός": "αμυντικός",
    "επίσημος": "ανεπίσημος",
    "ειλικρίνεια": "εγγύτητα",
    "αντίθετος": "χωρίς αντίσταση",
    "απεναντι απο": "εναλλακτικό",
    "αισιοδοξία": "απαισιοδοξία",
    "αισιόδοξος": "απαισιόδοξος",
    "προαιρετικός": "υποχρεωτικός",
    "από το στόμα": "πρωκτικός",
    "σειρά": "διαταραχή",
    "τακτικός": "ακανόνιστος",
    "συνήθης": "ασυνήθης",
    "οργανικός": "ανόργανος",
    "διοργάνωσε": "αδιοργάνωτος",
    "ορθόδοξος": "ανορθόδοξος",
    "εξωτερικου χωρου": "μέσα",
    "εκτός νόμου": "νομιμοποιώ",
    "υπερτιμώ": "υποτιμώ",
    "πάνω από το κεφάλι": "επιφάνεια",
    "φανερός": "συγκαλυμμένος",
    "πακέτο": "ανοίγω τις αποσκευές",
    "επώδυνος": "ανώδυνος",
    "ανώδυνος": "επώδυνος",
    "παράλληλο": "λοξός",
    "κάθετος": "λοξός",
    "μητρική εταιρεία": "παιδί",
    "μεροληψία": "αμεροληψία",
    "λεπτομέρεια": "γενικότητα",
    "εν μέρει": "όλως",
    "μέτριος": "αδιάβατος",
    "πέρασμα": "τρέξιμο",
    "ορθοστασία": "τρέξιμο",
    "το παρελθόν": "μελλοντικός",
    "παρόν": "απών",
    "πατρικός": "μητρικός",
    "υπομονή": "ανυπομονησία",
    "υπομονετικος": "ανυπόμονος",
    "υποστηρίζω": "μποϋκοτάζ",
    "ειρήνη": "πόλεμος",
    "ποινή": "ανταμοιβή",
    "αντιληπτός": "ανεπαίσθητος",
    "τελειότητα": "ατέλεια",
    "διαπερατός": "αδιαπέραστος",
    "επιτρεπτός": "είναι απαράδεκτο",
    "επιτρεπτικός": "προληπτικός",
    "προσωπικός": "απρόσωπος",
    "πείθω": "αποτρέπω",
    "απαισιοδοξία": "αισιοδοξία",
    "απαισιόδοξος": "αισιόδοξος",
    "φυσικός": "διανοητικός",
    "πεδιάδα": "φαντασία",
    "ενάγων": "εναγόμενος",
    "ευχαριστημένος": "μη ικανοποιημένοι",
    "πληθυντικός": "ενικός",
    "πολικός": "ισημερινού",
    "ευγενικός": "αγενής",
    "δημοφιλής": "μη δημοφιλής",
    "αραιότητα της ύλης": "στερεότητα",
    "δυνατότητα": "αδύνατο",
    "οπίσθιο": "προηγούμενος",
    "ισχυρός": "ανίσχυρος",
    "δυνητικός": "πραγματικός",
    "φτώχεια": "πλούτος",
    "ανίσχυρος": "ισχυρός",
    "έπαινος": "κριτικάρω",
    "προηγούμαι": "πετυχαίνω",
    "πρόθεμα": "κατάληξη",
    "παρασκευή": "ανάλυση",
    "έτοιμος": "απροετοίμαστος",
    "εντεταλμένος": "περιγραφικός",
    "παρουσία": "απουσία",
    "διατηρούνται": "καταστράφηκε από",
    "προληπτικός": "επιτρεπτικός",
    "πρωταρχικός": "δευτερεύων",
    "ιδιωτικός": "δημόσιο",
    "ιδιαιτερώς": "δημοσίως",
    "πιθανός": "απίθανος",
    "παραγωγικός": "μη παραγωγικός",
    "βέβηλος": "ιερός",
    "επαγγελματίας": "ερασιτέχνης",
    "πρόοδος": "οπισθοχώρηση",
    "προοδευτικός": "οπισθοδρομικός",
    "υποψήφιος": "αναδρομικός",
    "προστατεύονται": "απροστάτευτος",
    "υπερήφανος": "ταπεινός",
    "αποδεικνύω": "ανασκευάζω",
    "εγγύτατος": "τελικός",
    "συνετός": "ασύνετος",
    "δημόσιο": "ιδιωτικός",
    "δημοσίως": "ιδιαιτερώς",
    "δημοσίευσε": "αδημοσίευτος",
    "τραβήξτε": "σπρώξτε",
    "ακρίβεια": "βραδύτητα",
    "καθαρίζω": "αποκαθιστώ",
    "καθαρότητα": "ακαθαρσία",
    "σπρώξτε": "τραβήξτε",
    "έχω τα προσόντα": "καθιστώ ακατάλληλο",
    "βασίλισσα": "βασιλιάς",
    "ερώτηση": "απάντηση",
    "αμφισβητήσιμος": "αναμφισβήτητος",
    "γρήγορα": "αργά",
    "ρεαλιστικός": "απραγματοποίητος",
    "καθησυχάζω": "ανησυχία",
    "ανάκληση": "θέμα",
    "ρεκόρ": "εξάλειψη",
    "επωδός": "ενεργω",
    "αρνηθεί": "αποδέχομαι",
    "οπισθοχώρηση": "πρόοδος",
    "κανονικότητα": "παρατυπία",
    "ρυθμιζόμενη": "μη ρυθμισμένη",
    "αποκαθιστώ": "καθαρίζω",
    "απόρριψη": "αποδοχή",
    "ξανανιώνω": "ηλικία",
    "σχετίζεται με": "άσχετος",
    "συγγενής": "απόλυτος",
    "σχετικό": "άσχετος",
    "αξιόπιστος": "αναξιόπιστος",
    "θρησκευτικός": "κοσμικός",
    "αποστροφή": "αξιοθεατο",
    "ευυπόληπτος": "ανυπόληπτος",
    "υπόληψη": "ανυποληψία",
    "αντιστέκομαι": "παράδοση",
    "σεβασμός": "έλλειψη σεβασμού",
    "γεμάτος σεβασμό": "ασεβής",
    "υπεύθυνος": "ανεύθυνος",
    "συγκρατημένος": "ασυγκράτητος",
    "περιορισμένος": "απεριόριστος",
    "αναδρομικός": "υποψήφιος",
    "αντιστροφή": "επιβεβαίωση",
    "ανταμοιβή": "ποινή",
    "βόλτα": "περπατήστε",
    "ώριμος": "πράσινος",
    "αυξανόμενες": "πτώση",
    "στροφείο": "στάτωρ",
    "τραχύτητα": "ομαλότητα",
    "γύρος": "τετράγωνο",
    "στρογγυλεμένες": "γωνιώδης",
    "αγροτικός": "αστικός",
    "βιασύνη": "αργοπορώ",
    "ιερός": "βέβηλος",
    "δυστυχώς": "ευτυχώς",
    "θλίψη": "ευτυχία",
    "δυστυχία": "ευτυχία",
    "ασφαλής": "επικίνδυνος",
    "ασφάλεια": "ανασφάλεια",
    "ομοιότητα": "διαφορά",
    "λογική": "παράνοια",
    "ικανοποίηση": "δυσαρέσκεια",
    "αλμυρά": "ανούσιος",
    "επιστημονικός": "μη επιστημονικός",
    "ευσυνείδητος": "ασυνείδητος",
    "δευτερεύων": "πρωταρχικός",
    "κοσμικός": "θρησκευτικός",
    "διαχωρισμός": "ένωση",
    "εγωιστικός": "ανιδιοτελής",
    "πουλώ": "αγορά",
    "αρχαιότερος": "κατώτερος",
    "ξεχωριστός": "άρθρωση",
    "σηπτικός": "αντισηπτικό",
    "υπηρεσία": "κακή υπηρεσία",
    "τακτοποιημένο": "άστατος",
    "ακονίζω": "ισοπεδώνω",
    "μικρός": "ψηλός",
    "βραχύνω": "επιμηκύνω",
    "προβολή": "κρύβω",
    "πλευρά": "κάτω μέρος",
    "μπλουζα": "κάτω μέρος",
    "σημασία": "ασημαντότητα",
    "σημαντικός": "ασήμαντος",
    "παρόμοιος": "ανόμοιος",
    "απλός": "χημική ένωση",
    "απλοποιώ": "περιπλέκω",
    "μονόκλινο": "πολλαπλούς",
    "ενικός": "πληθυντικός",
    "νεροχύτης": "πηγή",
    "αδελφή": "αδελφός",
    "ύπνος": "ίχνη",
    "μικρό": "μεγάλο",
    "ομαλότητα": "τραχύτητα",
    "απαλότητα": "οξύτητα",
    "στερεότητα": "αραιότητα της ύλης",
    "διαλυτός": "αδιάλυτος",
    "φερεγγυότητα": "αφερεγγυότητα",
    "διαλυτικό μέσο": "αφερέγγυος",
    "υιός": "κόρη",
    "λύπη": "χαρά",
    "θλιμμένος": "χαρούμενος",
    "ομιλούμενος": "γραπτός",
    "άγραφος": "γραπτός",
    "σποραδικός": "συνεχής",
    "διάδοση": "μαζεύω",
    "τετράγωνο": "γύρος",
    "σταθερότητα": "αστάθεια",
    "σταθερός": "ασταθής",
    "στάση": "απόδοση παραγωγής",
    "στάτωρ": "στροφείο",
    "διαμονή": "κίνηση",
    "σταθερά": "ασταθής",
    "απότομος": "βαθμιαίος",
    "αιφνίδιος": "βαθμιαίος",
    "στείρος": "εύφορος",
    "σκληρύνω": "αμολάω",
    "τσιγκούνης": "γενναιόδωρος",
    "θυελλώδης": "ηρεμία",
    "ευθεία": "κυρτός",
    "ισιώνω": "στροφή",
    "ξένος": "γνωριμία",
    "δύναμη": "αδυναμία",
    "τέντωμα": "μαζεύω",
    "δυνατά": "ασθενώς",
    "στούντιο": "τοποθεσία",
    "βλακεία": "νοημοσύνη",
    "υποκειμενικός": "σκοπός",
    "υφιστάμενος": "κυρίαρχο",
    "μεταγενέστερος": "προηγούμενος",
    "ουσιαστικό": "επίθετο",
    "αφαιρώ": "προσθέτω",
    "αφαίρεση": "πρόσθεση",
    "επιτυχία": "αποτυχία",
    "επιτυχής": "ανεπιτυχής",
    "υποκύπτω": "επιζώ",
    "υποφέρω": "απολαμβάνω",
    "επαρκώς": "ανεπαρκώς",
    "ανατολή ηλίου": "η δυση του ηλιου",
    "η δυση του ηλιου": "ανατολή ηλίου",
    "ανώτερος": "κατώτερος",
    "υπεροχή": "κατωτερότητα",
    "προμήθεια": "ζήτηση",
    "υποστηρίζεται": "ανυποστήρικτος",
    "επιφάνεια": "πάνω από το κεφάλι",
    "παράδοση": "αντιστέκομαι",
    "επιζώ": "υποκύπτω",
    "γλυκός": "θυμώνω",
    "βρεγμένος": "ξηρός",
    "γλυκαίνω": "θυμώνω",
    "συμμετρία": "ασυμμετρία",
    "συμπονετικός": "άπονος",
    "συνεργιστική": "ανταγωνιστικός",
    "σύνθεση": "ανάλυση",
    "συνθετικός": "αναλυτικός",
    "βραδύτητα": "ακρίβεια",
    "καλαίσθητος, έχων καλό γούστο": "άγευστος",
    "γευστικός": "άγευστος",
    "άγευστος": "γευστικός",
    "προσφορά": "σκληρός",
    "σε υπερένταση": "χαλαρή",
    "τερματικό": "ενδιάμεσος",
    "θεϊσμός": "αθεϊσμός",
    "θεωρητικός": "εμπειρικός",
    "διψασμένος": "πεινασμένος",
    "προσεκτικός": "ξένοιαστος",
    "επιπόλαιος": "προσεκτικός",
    "λιτός": "σπάταλος",
    "παλίρροια": "άμπωτη",
    "γραβάτα": "λύνω",
    "ανοχή": "μισαλλοδοξία",
    "ανεκτικός": "μισαλλόδοξος",
    "οδοντωτός": "φαφούτης",
    "φαφούτης": "οδοντωτός",
    "συγκενημένος": "άθικτος",
    "σκληρός": "προσφορά",
    "ήμερος": "ατίθασος",
    "τραγωδία": "κωμωδία",
    "εκπαιδευμένο": "αγύμναστος",
    "εμπιστοσύνη": "δυσπιστία",
    "αλήθεια": "ψευτιά",
    "ασχημία": "ομορφιά",
    "άσχημος": "πανεμορφη",
    "τελικός": "εγγύτατος",
    "απαράδεκτος": "δεκτός",
    "μη αναγνωρισμένο": "αναγνωρίζεται",
    "αμεταποίητος": "μεταβληθεί",
    "ξεκάθαρος": "διφορούμενος",
    "άοπλος": "ένοπλος",
    "ανεξουσιοδότητος": "εξουσιοδοτημένο",
    "ανισόρροπος": "ισορροπημένη",
    "άδετος": "όριο",
    "άθραυστος": "σπασμένος",
    "αβεβαιότητα": "βεβαιότητα",
    "θείος": "θεία",
    "ασυνήθης": "συνήθης",
    "αδιάφορος": "ενδιαφερόμενος",
    "ανεξακρίβωτος": "επιβεβαιωμένος",
    "αναισθησία": "συνείδηση",
    "αντισυνταγματικός": "συνταγματικός",
    "πρωτότυπος": "συμβατικός",
    "ακατάπειστος": "πεπεισμένοι",
    "αποκαλύπτω": "βέλο",
    "άκοπος": "τομή",
    "απροσδιόριστος": "ορίζεται",
    "υποτιμώ": "υπερτιμώ",
    "ανεπιθύμητος": "επιθυμητός",
    "υπερβολικός": "λόγω",
    "αμόρφωτος": "μορφωμένος",
    "ήσυχος": "περιστασιακή",
    "απροσδόκητος": "αναμενόμενος",
    "άπιστος": "πιστός",
    "άγνωστος": "οικείος",
    "ξεδιπλωθεί": "πτυχή",
    "ανελέητος": "επιεικής",
    "ατυχής": "τυχερός",
    "αχάριστος": "ευγνώμων",
    "δυστυχής": "ευτυχισμένος",
    "ανθυγιεινός": "υγιής",
    "ανίερος": "άγιος",
    "ανευ σημασιας": "σπουδαίος",
    "αβελτίωτος": "βελτίωση",
    "απληροφόρητος": "προειδοποίητος",
    "ακατοίκητος": "κατοικημένη",
    "ακατάληπτος": "καταληπτός",
    "ακούσια": "εκ προθέσεως",
    "πληκτικός": "ενδιαφέρων",
    "ένωση": "διαχωρισμός",
    "ενιαία": "ομοσπονδιακός",
    "ενωμένος": "διαιρεμένη",
    "αφιλοφρών": "είδος",
    "απεριόριστος": "περιορισμένος",
    "ξεκλείδωμα": "κλειδαριά",
    "άτυχος": "τυχερός",
    "αβαθμολόγητος": "μαρκαρισμένος",
    "άγαμος": "παντρεμένος",
    "ανακαλύπτω": "μάσκα",
    "αδειανός": "κατειλημμένος",
    "ανεπίσημος": "επίσημος",
    "χωρίς αντίσταση": "αντίθετος",
    "ανορθόδοξος": "ορθόδοξος",
    "ανοίγω τις αποσκευές": "πακέτο",
    "μη δημοφιλής": "δημοφιλής",
    "απροετοίμαστος": "έτοιμος",
    "μη παραγωγικός": "παραγωγικός",
    "απροστάτευτος": "προστατεύονται",
    "αδημοσίευτος": "δημοσίευσε",
    "αναμφισβήτητος": "αμφισβητήσιμος",
    "απραγματοποίητος": "ρεαλιστικός",
    "μη ρυθμισμένη": "ρυθμιζόμενη",
    "αναξιόπιστος": "αξιόπιστος",
    "ασυγκράτητος": "συγκρατημένος",
    "ανούσιος": "αλμυρά",
    "μη επιστημονικός": "επιστημονικός",
    "ασυνείδητος": "ευσυνείδητος",
    "ανιδιοτελής": "εγωιστικός",
    "άστατος": "τακτοποιημένο",
    "ασταθής": "σταθερά",
    "ανεπιτυχής": "επιτυχής",
    "ανυποστήρικτος": "υποστηρίζεται",
    "άπονος": "συμπονετικός",
    "λύνω": "γραβάτα",
    "άθικτος": "συγκενημένος",
    "αγύμναστος": "εκπαιδευμένο",
    "ξένοιαστος": "προσεκτικός",
    "ακουσίως": "οικειοθελώς",
    "απροθυμία": "προθυμία",
    "ξετυλίγω": "άνεμος",
    "ανάξιος": "άξιος",
    "αστικός": "αγροτικός",
    "πολύτιμος": "άνευ αξίας",
    "βέλο": "αποκαλύπτω",
    "προφορικός": "αριθμητικός",
    "νίκη": "ήττα",
    "ενάρετος": "κακός",
    "ορατότητα": "αόρατο",
    "ορατός": "αόρατος",
    "φωνητικός": "ενόργανος",
    "εθελοντικώς": "ακούσιος",
    "φωνήεν": "σύμφωνο",
    "ίχνη": "ύπνος",
    "περπατήστε": "βόλτα",
    "παρακμή": "κερί",
    "πόλεμος": "ειρήνη",
    "απόβλητα": "συντηρώ",
    "σπάταλος": "λιτός",
    "κερί": "παρακμή",
    "ασθενώς": "δυνατά",
    "πλούτος": "φτώχεια",
    "χωρίς βαρύτητα": "βαρύς",
    "βαρύς": "χωρίς βαρύτητα",
    "ψίθυρος": "κραυγή",
    "άσπρο": "μαύρος",
    "όλως": "εν μέρει",
    "κακός": "ενάρετος",
    "ευρύς": "στενός",
    "ευρύνω": "στενός",
    "οικειοθελώς": "ακουσίως",
    "προθυμία": "απροθυμία",
    "άνεμος": "ξετυλίγω",
    "σοφία": "τρέλα",
    "σοφός": "ανόητος",
    "αποσύρω": "κατάθεση",
    "ανησυχία": "καθησυχάζω",
    "άνευ αξίας": "πολύτιμος",
    "άξιος": "ανάξιος",
    "γραπτός": "άγραφος",
    "νέος": "ηλικιωμένος",
    "ζενίθ": "ναδίρ",
}
